juliet --- a versatile modelling tool for transiting and non-transiting exoplanetary systems
---

![Juliet logo](juliet.png?raw=true)

Authors: Néstor Espinoza (espinoza@mpia.de) & Diana Kossakowski (kossakowski@mpia.de)

> For usage and dependencies, **check the documentation at http://juliet.readthedocs.io.**
> Don't forget to [check out the paper](https://arxiv.org/abs/1812.08549).
> For citation, see [this link](https://github.com/nespinoza/juliet/wiki/Citing-the-code).

Acknowledgments: We would like to thank our referee, Daniel Foreman-Mackey (https://github.com/dfm) for very useful code and paper review and suggestions. Also to Raphael Gyory (https://github.com/raphaelgyory) for helping us with releasing the pip package and readthedocs for the project.
